@@ -7,4 +7,7 @@ class GiverForm(forms.ModelForm):
 
     class Meta:
         model = Giver
-        exclude= ('gift',)
+
+        widgets = {
+            'gift': forms.HiddenInput,
+        }
